# Project Documentation

Telliot is documented using [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/).

The latest `telliot-core` documentation can be [found here](https://tellor-io.github.io/telliot-core/)

To compile and view local changes to documentation, 
use the following command, then open a browser to the link displayed:

    mkdocs serve

